#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['ipx800']

package_data = \
{'': ['*']}

install_requires = \
['requests']

setup(name='gce-ipx800',
      version='0.2',
      description='Module to control the IPX800 V4 device from GCE Electronics.',
      author='Marc-Aurèle Brothier',
      author_email='m@brothier.org',
      url='https://github.com/marcaurele/py-ipx800',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
